/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import { euiThemeVars } from '@kbn/ui-theme';
import type { VulnSeverity } from '@kbn/cloud-security-posture-common';
import { VULNERABILITIES_SEVERITY } from '@kbn/cloud-security-posture-common';

export const getCvsScoreColor = (score: number): string | undefined => {
  if (score <= 4) {
    return euiThemeVars.euiColorVis0; // low severity
  } else if (score >= 4 && score <= 7) {
    return euiThemeVars.euiColorVis7; // medium severity
  } else if (score >= 7 && score <= 9) {
    return euiThemeVars.euiColorVis9; // high severity
  } else if (score >= 9) {
    return euiThemeVars.euiColorDanger; // critical severity
  }
};

export const getSeverityStatusColor = (severity: VulnSeverity): string => {
  switch (severity) {
    case VULNERABILITIES_SEVERITY.LOW:
      return euiThemeVars.euiColorVis0;
    case VULNERABILITIES_SEVERITY.MEDIUM:
      return euiThemeVars.euiColorVis5_behindText;
    case VULNERABILITIES_SEVERITY.HIGH:
      return euiThemeVars.euiColorVis9_behindText;
    case VULNERABILITIES_SEVERITY.CRITICAL:
      return euiThemeVars.euiColorDanger;
    default:
      return '#aaa';
  }
};
