/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import { euiThemeVars } from '@kbn/ui-theme';
import { getVulnerabilityStats } from './vulnerability_helpers';
import { i18n } from '@kbn/i18n';

describe('getVulnerabilitiesAggregationCount', () => {
  it('should return empty array when all severity count is 0', () => {
    const result = getVulnerabilityStats({ critical: 0, high: 0, medium: 0, low: 0, none: 0 });
    expect(result).toEqual([]);
  });

  it('should return stats for low, medium, high, and critical vulnerabilities', () => {
    const result = getVulnerabilityStats({ critical: 1, high: 2, medium: 3, low: 4, none: 5 });

    expect(result).toEqual([
      {
        key: i18n.translate(
          'xpack.securitySolution.flyout.right.insights.vulnerabilities.noneVulnerabilitiesText',
          {
            defaultMessage: 'None',
          }
        ),
        count: 5,
        color: '#aaa',
      },
      {
        key: i18n.translate(
          'xpack.securitySolution.flyout.right.insights.vulnerabilities.lowVulnerabilitiesText',
          {
            defaultMessage: 'Low',
          }
        ),
        count: 4,
        color: euiThemeVars.euiColorVis0,
      },
      {
        key: i18n.translate(
          'xpack.securitySolution.flyout.right.insights.vulnerabilities.mediumVulnerabilitiesText',
          {
            defaultMessage: 'Medium',
          }
        ),
        count: 3,
        color: euiThemeVars.euiColorVis5_behindText,
      },
      {
        key: i18n.translate(
          'xpack.securitySolution.flyout.right.insights.vulnerabilities.highVulnerabilitiesText',
          {
            defaultMessage: 'High',
          }
        ),
        count: 2,
        color: euiThemeVars.euiColorVis9_behindText,
      },
      {
        key: i18n.translate(
          'xpack.securitySolution.flyout.right.insights.vulnerabilities.CriticalVulnerabilitiesText',
          {
            defaultMessage: 'Critical',
          }
        ),
        count: 1,
        color: euiThemeVars.euiColorDanger,
      },
    ]);
  });
});
